import Article from "@/components/Article";

const ArticleAcupunctureLetter = () => {
  return (
    <Article title="Acupuncture Letter" author="">
      <h2>
        TO: Members of The White House Commission On Complementary and
        Alternative Medicine Policy
      </h2>
      <p>FROM: Marshall H. Sager, D.O.</p>
      <p>President-Elect</p>
      <p>The American Academy Of Medical Acupuncture</p>
      <p>DATE: November 28, 2000</p>
      <p>
        RE: December 5-6 Commission Meeting on Guidance for Access to, Delivery
        of, and Reimbursement for Complementary and Alternative Medicine
        Practices and Interventions.
      </p>
      <h2>INTRODUCTION</h2>
      <p>
        The ancient medical modality of acupuncture is rapidly evolving as an
        effective complimentary paradigm within the framework of modern American
        medicine. Since President Nixon’s trip to China in 1972, and the New
        York Times’ James Reston’s dramatic appendectomy during that trip,
        interest in, and the popularity of, acupuncture has surged in America.
        This popular pressure has led to scientific investigation of
        acupuncture’s physiologic impact by the World Health Organization and,
        most recently, by the National Institutes of Health (NIH). Studies by
        these august bodies have concentrated on pain management and various
        disease entities and health problems as well as the integration of
        acupuncture into contemporary medical practice. The results of these
        studies have been positive and enlightening, lending credence to the
        efficacy of acupuncture – a medical paradigm which has persisted for
        more than 5,000 years.
      </p>
      <p>
        Medical Acupuncture, as distinguished from acupuncture, is the clinical
        discipline of acupuncture as practiced by a physician who is also
        trained and licensed in western bio-medicine. With its foundation in
        ancient Chinese medical theory and practice, Medical Acupuncture has
        become a therapeutic partner with conventional western bio-pharmacology.
        A physician who practices Medical Acupuncture offers a uniquely
        comprehensive approach to patient health care – an approach that
        combines western and eastern medical modalities. In other words — the
        best of both worlds.
      </p>
      <p>
        Physicians who practice Medical Acupuncture treat as wide a spectrum of
        medical challenges as do their western bio-medically-oriented
        counterparts. The distinction lies in basic philosophy. While western
        physicians treat problems people have, the Medical Acupuncture physician
        treats people with problems. With Medical Acupuncture, the concentration
        is on the well-being and health of the whole person. The goal is to
        restore the individual to a state of balance and harmony within
        him/herself and with his/her environment. This is in contrast to the
        traditional western medical approach which concentrates on ameliorating
        or combating a particular problem or symptom. As the Medical Acupuncture
        physician is well versed in both western and eastern paradigms, he/she
        can combine acupuncture effectively with conventional medical or
        surgical interventions.
      </p>
      <p>
        The American Academy of Medical Acupuncture (AAMA) has experienced an
        approximately 20 percent annual membership increase over the last 5
        years. Its current membership is nearly 2,000 physicians. As the only
        medical specialty society for physicians practicing acupuncture in North
        America, the AAMA is a leader in establishing and maintaining the
        highest standards of training and continuing education in practice of
        Medical Acupuncture. The AAMA is committed to the pursuit of excellence
        in this field of medicine and will continue to maintain this ideal as
        its highest priority.
      </p>
      <p>
        Just as there are many sub-specialties within western medicine, so there
        are multiple disciplines within the practice of Medical Acupuncture and
        all of them are represented in the AAMA’s membership. The training and
        practice requirements for membership in the AAMA are based on
        international standards and serve as a model for state licensure of
        medical acupuncture physicians, hospital practice privileges, liability
        coverage and third party reimbursement.
      </p>
      <h2>DEFINITION OF MEDICAL ACUPUNCTURE AND PHYSICIAN RIGHTS</h2>
      <p>
        Acupuncture practice by physicians falls within the scope of the
        practice of medicine. Medical acupuncture specifically represents the
        use of acupuncture by fully trained and licensed physicians. By
        effectively combining the practices of western and eastern medicine, the
        Medical Acupuncturist fills a unique and critical role in patient care.
        Once again, we reiterate – the best of both worlds.
      </p>
      <p>
        The AAMA adamantly believes that appropriately trained Medical
        Acupuncture physicians must be permitted to use his/her knowledge and
        skill to benefit his/her patients. Healing is both an art and a science.
        The ability to help and to heal is the ultimate privilege. This ability
        must not be abridged or curtailed in any way. Understanding the depth of
        commitment of physician acupuncturists and regulating their practice
        rights must come from one’s peers. Therefore, the AAMA contends that, as
        is the case with any other medical specialty, regulation of physicians
        practicing acupuncture must come only from medical boards.
      </p>
      <p>
        Incredulously, the medical acupuncturists’ private practice rights are
        currently threatened by the restructuring of health care delivery and
        reimbursement. The AAMA seeks protection of the physician
        acupuncturists’ rights, appropriate endorsement by the conventional
        medical establishment and recognition by health care providers of
        medical acupuncture physicians whose practice may be uniquely different
        from that of their other medical colleagues as well as non-physician
        acupuncture practitioners.
      </p>
      <h2>ACUPUNCTURE QUALIFICATIONS FOR PHYSICIANS </h2>
      <p>
        The AAMA requires all members to be graduates of accredited American
        medical schools with more that 4,000 hours of allopathic education and
        licensed to practice medicine in their State. In addition, the AAMA
        requires 200 hours of formal, approved acupuncture instruction,
        consisting of 120 hours of didactic education and 80 hours of clinical
        training followed by two years of clinical acupuncture practice.
        Satisfaction of each and every one of these requirements entitles a
        physician acupuncturist to Full Practice Membership in the AAMA. The
        AAMA also requires each member physician to fulfill 50 hours of approved
        continuing education in acupuncture every three years.
      </p>
      <p>
        These requirements are consistent with the world-wide standards
        established by the World Health Organization and the World Federation of
        Acupuncture/Moxibustion Societies.
      </p>
      <p>
        After completing comprehensive training, medical acupuncture physicians
        are eligible to sit for an exhaustive examination which could lead to
        board certification through the American Board of Medical Acupuncture.
        This examination is the most comprehensive measure of expertise in the
        multiple disciplines of acupuncture in the world.
      </p>
      <p>
        COMPLEMENTARY AND ALTERNATIVE MEDICINE ACCESS, DELIVERY AND
        REIMBURSEMENT
      </p>
      <p>
        It is of little value to have the potential for receiving the best
        medical care in the world if access to that care it is routinely
        blocked. This is precisely the case with delivery of Medical Acupuncture
        services throughout America. And this problem is critically and sadly
        magnified for the elderly — those who would most benefit from easy
        access to Medical Acupuncture.
      </p>
      <p>
        Reimbursement for Medical Acupuncture services is sparse, at best in
        21st century America. Essentially, these medical services are limited to
        those patients who can afford to pay out of pocket. While physicians are
        routinely reimbursed by third party payers for conventional Western
        medical paradigm related services such as Evaluation and Management
        (E&amp;M), rehabilitation, inoculations and the like, payment for and
        access to the ancient, well-respected and effective medical practice and
        intervention of Medical Acupuncture is generally precluded. This is
        illogical and disturbing, especially when we consider caring for our
        elderly – those who could benefit significantly from easy access to
        Medical Acupuncture therapy. Let us not forget that the elderly suffer
        from chronic and painful problems which are often uncontrolled by
        bio-pharmaceuticals. Let us also not forget that our elderly are most
        likely to suffer from drug interactions and adverse side effects. And
        finally, let us not forget that Medical Acupuncture is side-effect free,
        painless and effective. Those of us who care respectfully request — no,
        we demand that this inequity be remedied.
      </p>
      <p>
        Unfortunately, there is no “quick fix’ to this problem. It must begin
        with today’s medical students and extend to continuing medical education
        programs throughout the nation. Medical students and physicians must be
        educated about the use and effectiveness of all complimentary medical
        modalities, especially Medical Acupuncture. And they must understand
        that, when administered by a licensed physician, Medical Acupuncture is
        an ideal compliment to traditional western drug and surgical
        interventions. They must understand its benefits and applications so as
        to be able to inform their patients of the conventional, complimentary
        and alternative medical options and choices available to them. And they
        must understand that Medical Acupuncture is not a threat to their
        practice, it is an enhancement to their success.
      </p>
      <p>
        In the present medical reimbursement climate, knowledgeable physicians
        who prescribe complimentary and alternative medical interventions must
        constantly weigh the insurance coverage considerations against the
        out-of-pocket burden both for themselves and their patients. Being able
        to assess every patient from both Western and Eastern vantage points
        represents a remarkable advantage for the patient. Again, we repeat, the
        best of both worlds. Insuring that physician acupuncturists are
        appropriately compensated for their expertise and time insures the
        integrity of the practice of Medical Acupuncture and the safety of the
        patients. The best and the brightest will not be able to afford the
        extraordinary amount of time and emotional commitment to learning this
        complex paradigm if they will not be appropriately compensated at the
        end of their efforts.
      </p>
      <p>
        This fact of non-reimbursement for physician acupuncturist is causing a
        strain on our healthcare system. The fact that most health care plans do
        not reimburse for physician acupuncturists has forced patients from
        their primary medical care providers and out of the healthcare system.
        This tends to fractionalize health care – a less than desired condition.
        Furthermore, a disparity in health care delivery that borders on
        discriminatory is created with the poor patient unable to participate
        because of limited out-of- pocket resources.
      </p>
      <p>
        Finally, we must look at hospital care in America. Earlier I mentioned
        famed columnist James Reston. In China, he benefited from acupuncture
        analgesia and anesthesia. Yet in America there is a virtual dearth of
        Medical Acupuncture in the hospital setting. This must be changed.
        Hospitalized patients can benefit enormously from Medical Acupuncture to
        alleviate pain and expedite recovery. Medical Acupuncture saves money.
        Patients recover faster. Post hospitalization office visits are reduced.
        Everyone benefits.
      </p>
      <p>
        In fact, that’s the main point of my presentation. Medical Acupuncture
        creates win-win scenarios. Patients benefit by a speedy recovery and
        bio-pharmaceutical reduction. Surgeons benefit because their patients
        heal faster. Hospitals benefit because of shorter hospital stays. The
        public benefits because of reduced health care costs. A win-win all
        around.
      </p>
      <p>Thank you for your time and consideration.</p>
      <em>Marshall H. Sager, D.O.</em>
    </Article>
  );
};

export default ArticleAcupunctureLetter;
