import Article from "@/components/Article";
import griefPic from "@/public/content/stages_of_grief.png";
import Image from "next/image";

const ArticleTenStagesOfGrief = () => {
  return (
    <Article
      title="The Ten Stages of Grief"
      author="Richard A. Feely, D.O., FAAO, FCA, FAAMA"
    >
      <p>
        <strong>1. SHOCK:</strong> The initial stage of grief is usually
        experienced even if the death has been expected, as in a long terminal
        illness. There is only so much physical or psychic pain which can be
        endured by the mind, and when that limit is reached, the mental
        /emotional system shuts down. There is often denial that can last for
        quite some time. This is expressed as “numbness,” or as a sense of
        unreality.
      </p>

      <div className="flex justify-center">
        <Image src={griefPic} alt="Woman in grief" />
      </div>

      <p>
        <strong>2. EMOTIONAL RELEASE:</strong> As the shock wears off, there is
        a need to release all the emotions that have been building up. This
        release may be verbal or physical, and while this is healthy, care
        should be taken to ensure the safety of the individual, others, or
        personal property. Some hospitals have recognized this stage of grief
        and have provided special “screaming rooms” where these powerful
        emotions can be safely vented.
      </p>

      <p>
        <strong>3. DEPRESSION:</strong> There are often feelings of loneliness
        and utter isolation that come with depression. The feeling of “there is
        no help for me,” is normal and very common. There is a push/pull
        situation, wanting to be alone and yet feeling a need for people at the
        same time. This frequently produces fears of panic and impending
        insanity.
      </p>

      <p>
        <strong>4. PHYSICAL SYMPTOMS OF DISTRESS:</strong> The grieving
        individual will often take on the physical symptoms of the illness that
        caused the death of the loved one. In the event of an accident, the
        bereaved will sometimes feel pressure in the chest or have stomach
        problems, and fear heart attack or cancer. This is normal and usually
        indicates the depth of the loss and the person wishing to “join” the
        deceased.
      </p>

      <p>
        <strong>5. ANXIETY: </strong>A common response to loss is for the
        bereaved to experience vivid dreams of the deceased, so vivid that they
        believe they have actually seen or heard their loved one. Another common
        manifestation is that the bereaved will mistake another person for the
        deceased, usually on the street or in a store. This will sometimes cause
        great embarrassment as they may address the stranger, only to realize
        their mistake.
      </p>

      <p>
        <strong>6. HOSTILITY: </strong>When a loved one has died, it is very
        common for the survivor to feel anger at those who were involved in the
        situation, especially medical personnel and clergy. There is a feeling
        of “Why didn’t you do more?” God is a frequent target for this rage,
        which many people have a difficult time accepting.
      </p>

      <p>
        <strong>7. GULT:</strong> This emotion can be imaginary or exaggerated,
        but should not be ignored. Following the death, it is a common
        experience for the survivor to remember only the negative aspects of the
        relationship, those times of insensitivity or harsh words spoken in
        anger. Seldom does the bereaved pause and remember the beautiful times
        when all the love and tenderness were evident.
      </p>

      <p>
        <strong>8. HESITANCY TO RENEW NORMAL ACTIVITIES:</strong> There is often
        a fear of returning to the regular routine of living. This fear takes
        several aspects. There is concern about how people will respond to the
        bereaved; there is a desire to talk about the deceased but a fear of
        rejection; there is a pain that comes with hearing that “special” song,
        or seeing something in a store that brings back the memory of the loved
        one.
      </p>

      <p>
        <strong>9. HEALING OF MEMORIES:</strong> There is a slow realization
        that the painful memories are part of the healing process and must be
        integrated into the life of the bereaved. It is a time of reaching out,
        however tentatively, to embrace fully all that has happened and to
        accept that life must change if it is to continue. The memories become
        less frightening, and the sky a bit brighter as the bereaved begins to
        face the world with more and more confidence.
      </p>

      <p>
        <strong>10. ACCEPTANCE OF ONE’S NEW ROLE IN LIFE:</strong> Loss brings
        about changes. Whether it is the resumption of single life after years
        of marriage, or going on through the years without a parent, there must
        be the realization that a new role is to be accepted and lived. The
        cycle of life continues, and the bereaved can finally shed the cloak of
        grief and take on the robe of peace and renewal.
      </p>
    </Article>
  );
};

export default ArticleTenStagesOfGrief;
